aboutsummaryrefslogtreecommitdiff
path: root/include/render
diff options
context:
space:
mode:
Diffstat (limited to 'include/render')
-rw-r--r--include/render/gbm_allocator.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/render/gbm_allocator.h b/include/render/gbm_allocator.h
index f4627b90..d4cd233e 100644
--- a/include/render/gbm_allocator.h
+++ b/include/render/gbm_allocator.h
@@ -20,10 +20,10 @@ struct wlr_gbm_allocator {
};
/**
* Creates a new GBM allocator from a render FD.
*
* Takes ownership over the FD.
*/
-struct wlr_gbm_allocator *wlr_gbm_allocator_create(int render_fd);
+struct wlr_gbm_allocator *wlr_gbm_allocator_create(int drm_fd);
#endif
@@ -20,10 +20,10 @@ struct wlr_gbm_allocator {
};
/**
- * Creates a new GBM allocator from a render FD.
+ * Creates a new GBM allocator from a DRM FD.
*
* Takes ownership over the FD.